Remotior Sensus
===============

.. image:: _static/logo.png
    :width: 60pt
    :align: center


Remotior Sensus (which is Latin for "a more remote sense")
is a Python package that allows for the processing
of remote sensing images and GIS data.

**Source code:** https://github.com/semiautomaticgit/remotior_sensus

**Bug reports:** https://github.com/semiautomaticgit/remotior_sensus/issues



Documentation
_____________


.. toctree::
   :maxdepth: 3
   :titlesonly:

   introduction.rst
   installation.rst
   quickstart.rst
   api_tools.rst
   api_core.rst
   api.rst
   basic_tutorials.rst

`Except where otherwise noted, content of this work is licensed under a`
`Creative Commons Attribution-ShareAlike 4.0 International License
<http://creativecommons.org/licenses/by-sa/4.0/>`_.
